.. _maintainers:

***************************************
Guidelines for collection maintainers
***************************************

Thank you for being a community collection maintainer. This guide offers an overview of your responsibilities as a maintainer along with resources for additional information. The Ansible community hopes that you will find that maintaining a collection is as rewarding for you as having the collection content is for the wider community.

.. toctree::
   :maxdepth: 1

   maintainers_guidelines
   maintainers_workflow
   collection_contributors/collection_releasing

In addition to the information here, module maintainers should be familiar with:

* :ref:`General Ansible community development practices <ansible_community_guide>`
* Documentation on :ref:`module development <developing_modules>`
